@@ -12,7 +12,7 @@ class TestModel(unittest.TestCase):
     def setUp(self) -> None:
         self.create_dataset_vae = CreateTransformedVersionsVAE("tourism")
 
-        self.model = self.create_dataset_vae.fit(epochs=5)
+        self.model, _ = self.create_dataset_vae.fit(epochs=5)
         self.preds, self.z = self.create_dataset_vae.predict(self.model)
 
     def test_compute_similarity(self):
